# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: discord_kkv_store_value_models/v1/AcknowledgedApplicationDisclosures.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'discord_kkv_store_value_models/v1/AcknowledgedApplicationDisclosures.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJdiscord_kkv_store_value_models/v1/AcknowledgedApplicationDisclosures.proto\x12\x30\x64iscord_protos.discord_kkv_store_value_models.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x05\n\"AcknowledgedApplicationDisclosures\x12\x91\x01\n\x11\x61\x63ked_disclosures\x18\x01 \x03(\x0b\x32v.discord_protos.discord_kkv_store_value_models.v1.AcknowledgedApplicationDisclosures.AcknowledgedApplicationDisclosure\x1a\xed\x01\n!AcknowledgedApplicationDisclosure\x12\x87\x01\n\x0f\x64isclosure_type\x18\x01 \x01(\x0e\x32n.discord_protos.discord_kkv_store_value_models.v1.AcknowledgedApplicationDisclosures.ApplicationDisclosureType\x12\x31\n\x08\x61\x63ked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x42\x0b\n\t_acked_at\"\xfb\x01\n\x19\x41pplicationDisclosureType\x12\x36\n2APPLICATION_DISCLOSURE_TYPE_UNSPECIFIED_DISCLOSURE\x10\x00\x12+\n\'APPLICATION_DISCLOSURE_TYPE_IP_LOCATION\x10\x01\x12\x37\n3APPLICATION_DISCLOSURE_TYPE_DISPLAYS_ADVERTISEMENTS\x10\x02\x12@\n<APPLICATION_DISCLOSURE_TYPE_PARTNER_SDK_DATA_SHARING_MESSAGE\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'discord_kkv_store_value_models.v1.AcknowledgedApplicationDisclosures_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ACKNOWLEDGEDAPPLICATIONDISCLOSURES']._serialized_start=162
  _globals['_ACKNOWLEDGEDAPPLICATIONDISCLOSURES']._serialized_end=840
  _globals['_ACKNOWLEDGEDAPPLICATIONDISCLOSURES_ACKNOWLEDGEDAPPLICATIONDISCLOSURE']._serialized_start=349
  _globals['_ACKNOWLEDGEDAPPLICATIONDISCLOSURES_ACKNOWLEDGEDAPPLICATIONDISCLOSURE']._serialized_end=586
  _globals['_ACKNOWLEDGEDAPPLICATIONDISCLOSURES_APPLICATIONDISCLOSURETYPE']._serialized_start=589
  _globals['_ACKNOWLEDGEDAPPLICATIONDISCLOSURES_APPLICATIONDISCLOSURETYPE']._serialized_end=840
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class FrecencyUserSettings(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _GIFType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _GIFTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[FrecencyUserSettings._GIFType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        GIF_TYPE_NONE: FrecencyUserSettings._GIFType.ValueType  # 0
        GIF_TYPE_IMAGE: FrecencyUserSettings._GIFType.ValueType  # 1
        GIF_TYPE_VIDEO: FrecencyUserSettings._GIFType.ValueType  # 2

    class GIFType(_GIFType, metaclass=_GIFTypeEnumTypeWrapper): ...
    GIF_TYPE_NONE: FrecencyUserSettings.GIFType.ValueType  # 0
    GIF_TYPE_IMAGE: FrecencyUserSettings.GIFType.ValueType  # 1
    GIF_TYPE_VIDEO: FrecencyUserSettings.GIFType.ValueType  # 2

    @_typing.final
    class Versions(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        CLIENT_VERSION_FIELD_NUMBER: _builtins.int
        SERVER_VERSION_FIELD_NUMBER: _builtins.int
        DATA_VERSION_FIELD_NUMBER: _builtins.int
        client_version: _builtins.int
        server_version: _builtins.int
        data_version: _builtins.int
        def __init__(
            self,
            *,
            client_version: _builtins.int = ...,
            server_version: _builtins.int = ...,
            data_version: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["client_version", b"client_version", "data_version", b"data_version", "server_version", b"server_version"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class FavoriteGIF(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        FORMAT_FIELD_NUMBER: _builtins.int
        SRC_FIELD_NUMBER: _builtins.int
        WIDTH_FIELD_NUMBER: _builtins.int
        HEIGHT_FIELD_NUMBER: _builtins.int
        ORDER_FIELD_NUMBER: _builtins.int
        format: Global___FrecencyUserSettings.GIFType.ValueType
        src: _builtins.str
        width: _builtins.int
        height: _builtins.int
        order: _builtins.int
        def __init__(
            self,
            *,
            format: Global___FrecencyUserSettings.GIFType.ValueType = ...,
            src: _builtins.str = ...,
            width: _builtins.int = ...,
            height: _builtins.int = ...,
            order: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["format", b"format", "height", b"height", "order", b"order", "src", b"src", "width", b"width"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class FavoriteGIFs(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class GifsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            @_builtins.property
            def value(self) -> Global___FrecencyUserSettings.FavoriteGIF: ...
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: Global___FrecencyUserSettings.FavoriteGIF | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        GIFS_FIELD_NUMBER: _builtins.int
        HIDE_TOOLTIP_FIELD_NUMBER: _builtins.int
        hide_tooltip: _builtins.bool
        @_builtins.property
        def gifs(self) -> _containers.MessageMap[_builtins.str, Global___FrecencyUserSettings.FavoriteGIF]: ...
        def __init__(
            self,
            *,
            gifs: _abc.Mapping[_builtins.str, Global___FrecencyUserSettings.FavoriteGIF] | None = ...,
            hide_tooltip: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["gifs", b"gifs", "hide_tooltip", b"hide_tooltip"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class FavoriteStickers(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        STICKER_IDS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def sticker_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        def __init__(
            self,
            *,
            sticker_ids: _abc.Iterable[_builtins.int] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["sticker_ids", b"sticker_ids"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class FrecencyItem(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        TOTAL_USES_FIELD_NUMBER: _builtins.int
        RECENT_USES_FIELD_NUMBER: _builtins.int
        FRECENCY_FIELD_NUMBER: _builtins.int
        SCORE_FIELD_NUMBER: _builtins.int
        total_uses: _builtins.int
        frecency: _builtins.int
        score: _builtins.int
        @_builtins.property
        def recent_uses(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        def __init__(
            self,
            *,
            total_uses: _builtins.int = ...,
            recent_uses: _abc.Iterable[_builtins.int] | None = ...,
            frecency: _builtins.int = ...,
            score: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["frecency", b"frecency", "recent_uses", b"recent_uses", "score", b"score", "total_uses", b"total_uses"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class StickerFrecency(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class StickersEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___FrecencyUserSettings.FrecencyItem: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___FrecencyUserSettings.FrecencyItem | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        STICKERS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def stickers(self) -> _containers.MessageMap[_builtins.int, Global___FrecencyUserSettings.FrecencyItem]: ...
        def __init__(
            self,
            *,
            stickers: _abc.Mapping[_builtins.int, Global___FrecencyUserSettings.FrecencyItem] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["stickers", b"stickers"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class FavoriteEmojis(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        EMOJIS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def emojis(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
        def __init__(
            self,
            *,
            emojis: _abc.Iterable[_builtins.str] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["emojis", b"emojis"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class EmojiFrecency(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class EmojisEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            @_builtins.property
            def value(self) -> Global___FrecencyUserSettings.FrecencyItem: ...
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: Global___FrecencyUserSettings.FrecencyItem | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        EMOJIS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def emojis(self) -> _containers.MessageMap[_builtins.str, Global___FrecencyUserSettings.FrecencyItem]: ...
        def __init__(
            self,
            *,
            emojis: _abc.Mapping[_builtins.str, Global___FrecencyUserSettings.FrecencyItem] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["emojis", b"emojis"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ApplicationCommandFrecency(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class ApplicationCommandsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            @_builtins.property
            def value(self) -> Global___FrecencyUserSettings.FrecencyItem: ...
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: Global___FrecencyUserSettings.FrecencyItem | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        APPLICATION_COMMANDS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def application_commands(self) -> _containers.MessageMap[_builtins.str, Global___FrecencyUserSettings.FrecencyItem]: ...
        def __init__(
            self,
            *,
            application_commands: _abc.Mapping[_builtins.str, Global___FrecencyUserSettings.FrecencyItem] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["application_commands", b"application_commands"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class FavoriteSoundboardSounds(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        SOUND_IDS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def sound_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        def __init__(
            self,
            *,
            sound_ids: _abc.Iterable[_builtins.int] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["sound_ids", b"sound_ids"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ApplicationFrecency(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class ApplicationsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            @_builtins.property
            def value(self) -> Global___FrecencyUserSettings.FrecencyItem: ...
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: Global___FrecencyUserSettings.FrecencyItem | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        APPLICATIONS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def applications(self) -> _containers.MessageMap[_builtins.str, Global___FrecencyUserSettings.FrecencyItem]: ...
        def __init__(
            self,
            *,
            applications: _abc.Mapping[_builtins.str, Global___FrecencyUserSettings.FrecencyItem] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["applications", b"applications"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class HeardSoundFrecency(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class HeardSoundsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            @_builtins.property
            def value(self) -> Global___FrecencyUserSettings.FrecencyItem: ...
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: Global___FrecencyUserSettings.FrecencyItem | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        HEARD_SOUNDS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def heard_sounds(self) -> _containers.MessageMap[_builtins.str, Global___FrecencyUserSettings.FrecencyItem]: ...
        def __init__(
            self,
            *,
            heard_sounds: _abc.Mapping[_builtins.str, Global___FrecencyUserSettings.FrecencyItem] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["heard_sounds", b"heard_sounds"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class PlayedSoundFrecency(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class PlayedSoundsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            @_builtins.property
            def value(self) -> Global___FrecencyUserSettings.FrecencyItem: ...
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: Global___FrecencyUserSettings.FrecencyItem | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        PLAYED_SOUNDS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def played_sounds(self) -> _containers.MessageMap[_builtins.str, Global___FrecencyUserSettings.FrecencyItem]: ...
        def __init__(
            self,
            *,
            played_sounds: _abc.Mapping[_builtins.str, Global___FrecencyUserSettings.FrecencyItem] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["played_sounds", b"played_sounds"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GuildAndChannelFrecency(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class GuildAndChannelsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___FrecencyUserSettings.FrecencyItem: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___FrecencyUserSettings.FrecencyItem | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        GUILD_AND_CHANNELS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def guild_and_channels(self) -> _containers.MessageMap[_builtins.int, Global___FrecencyUserSettings.FrecencyItem]: ...
        def __init__(
            self,
            *,
            guild_and_channels: _abc.Mapping[_builtins.int, Global___FrecencyUserSettings.FrecencyItem] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["guild_and_channels", b"guild_and_channels"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    VERSIONS_FIELD_NUMBER: _builtins.int
    FAVORITE_GIFS_FIELD_NUMBER: _builtins.int
    FAVORITE_STICKERS_FIELD_NUMBER: _builtins.int
    STICKER_FRECENCY_FIELD_NUMBER: _builtins.int
    FAVORITE_EMOJIS_FIELD_NUMBER: _builtins.int
    EMOJI_FRECENCY_FIELD_NUMBER: _builtins.int
    APPLICATION_COMMAND_FRECENCY_FIELD_NUMBER: _builtins.int
    FAVORITE_SOUNDBOARD_SOUNDS_FIELD_NUMBER: _builtins.int
    APPLICATION_FRECENCY_FIELD_NUMBER: _builtins.int
    HEARD_SOUND_FRECENCY_FIELD_NUMBER: _builtins.int
    PLAYED_SOUND_FRECENCY_FIELD_NUMBER: _builtins.int
    GUILD_AND_CHANNEL_FRECENCY_FIELD_NUMBER: _builtins.int
    EMOJI_REACTION_FRECENCY_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def versions(self) -> Global___FrecencyUserSettings.Versions: ...
    @_builtins.property
    def favorite_gifs(self) -> Global___FrecencyUserSettings.FavoriteGIFs: ...
    @_builtins.property
    def favorite_stickers(self) -> Global___FrecencyUserSettings.FavoriteStickers: ...
    @_builtins.property
    def sticker_frecency(self) -> Global___FrecencyUserSettings.StickerFrecency: ...
    @_builtins.property
    def favorite_emojis(self) -> Global___FrecencyUserSettings.FavoriteEmojis: ...
    @_builtins.property
    def emoji_frecency(self) -> Global___FrecencyUserSettings.EmojiFrecency: ...
    @_builtins.property
    def application_command_frecency(self) -> Global___FrecencyUserSettings.ApplicationCommandFrecency: ...
    @_builtins.property
    def favorite_soundboard_sounds(self) -> Global___FrecencyUserSettings.FavoriteSoundboardSounds: ...
    @_builtins.property
    def application_frecency(self) -> Global___FrecencyUserSettings.ApplicationFrecency: ...
    @_builtins.property
    def heard_sound_frecency(self) -> Global___FrecencyUserSettings.HeardSoundFrecency: ...
    @_builtins.property
    def played_sound_frecency(self) -> Global___FrecencyUserSettings.PlayedSoundFrecency: ...
    @_builtins.property
    def guild_and_channel_frecency(self) -> Global___FrecencyUserSettings.GuildAndChannelFrecency: ...
    @_builtins.property
    def emoji_reaction_frecency(self) -> Global___FrecencyUserSettings.EmojiFrecency: ...
    def __init__(
        self,
        *,
        versions: Global___FrecencyUserSettings.Versions | None = ...,
        favorite_gifs: Global___FrecencyUserSettings.FavoriteGIFs | None = ...,
        favorite_stickers: Global___FrecencyUserSettings.FavoriteStickers | None = ...,
        sticker_frecency: Global___FrecencyUserSettings.StickerFrecency | None = ...,
        favorite_emojis: Global___FrecencyUserSettings.FavoriteEmojis | None = ...,
        emoji_frecency: Global___FrecencyUserSettings.EmojiFrecency | None = ...,
        application_command_frecency: Global___FrecencyUserSettings.ApplicationCommandFrecency | None = ...,
        favorite_soundboard_sounds: Global___FrecencyUserSettings.FavoriteSoundboardSounds | None = ...,
        application_frecency: Global___FrecencyUserSettings.ApplicationFrecency | None = ...,
        heard_sound_frecency: Global___FrecencyUserSettings.HeardSoundFrecency | None = ...,
        played_sound_frecency: Global___FrecencyUserSettings.PlayedSoundFrecency | None = ...,
        guild_and_channel_frecency: Global___FrecencyUserSettings.GuildAndChannelFrecency | None = ...,
        emoji_reaction_frecency: Global___FrecencyUserSettings.EmojiFrecency | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_application_command_frecency", b"_application_command_frecency", "_application_frecency", b"_application_frecency", "_emoji_frecency", b"_emoji_frecency", "_emoji_reaction_frecency", b"_emoji_reaction_frecency", "_favorite_emojis", b"_favorite_emojis", "_favorite_gifs", b"_favorite_gifs", "_favorite_soundboard_sounds", b"_favorite_soundboard_sounds", "_favorite_stickers", b"_favorite_stickers", "_guild_and_channel_frecency", b"_guild_and_channel_frecency", "_heard_sound_frecency", b"_heard_sound_frecency", "_played_sound_frecency", b"_played_sound_frecency", "_sticker_frecency", b"_sticker_frecency", "_versions", b"_versions", "application_command_frecency", b"application_command_frecency", "application_frecency", b"application_frecency", "emoji_frecency", b"emoji_frecency", "emoji_reaction_frecency", b"emoji_reaction_frecency", "favorite_emojis", b"favorite_emojis", "favorite_gifs", b"favorite_gifs", "favorite_soundboard_sounds", b"favorite_soundboard_sounds", "favorite_stickers", b"favorite_stickers", "guild_and_channel_frecency", b"guild_and_channel_frecency", "heard_sound_frecency", b"heard_sound_frecency", "played_sound_frecency", b"played_sound_frecency", "sticker_frecency", b"sticker_frecency", "versions", b"versions"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_application_command_frecency", b"_application_command_frecency", "_application_frecency", b"_application_frecency", "_emoji_frecency", b"_emoji_frecency", "_emoji_reaction_frecency", b"_emoji_reaction_frecency", "_favorite_emojis", b"_favorite_emojis", "_favorite_gifs", b"_favorite_gifs", "_favorite_soundboard_sounds", b"_favorite_soundboard_sounds", "_favorite_stickers", b"_favorite_stickers", "_guild_and_channel_frecency", b"_guild_and_channel_frecency", "_heard_sound_frecency", b"_heard_sound_frecency", "_played_sound_frecency", b"_played_sound_frecency", "_sticker_frecency", b"_sticker_frecency", "_versions", b"_versions", "application_command_frecency", b"application_command_frecency", "application_frecency", b"application_frecency", "emoji_frecency", b"emoji_frecency", "emoji_reaction_frecency", b"emoji_reaction_frecency", "favorite_emojis", b"favorite_emojis", "favorite_gifs", b"favorite_gifs", "favorite_soundboard_sounds", b"favorite_soundboard_sounds", "favorite_stickers", b"favorite_stickers", "guild_and_channel_frecency", b"guild_and_channel_frecency", "heard_sound_frecency", b"heard_sound_frecency", "played_sound_frecency", b"played_sound_frecency", "sticker_frecency", b"sticker_frecency", "versions", b"versions"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__application_command_frecency: _TypeAlias = _typing.Literal["application_command_frecency"]  # noqa: Y015
    _WhichOneofArgType__application_command_frecency: _TypeAlias = _typing.Literal["_application_command_frecency", b"_application_command_frecency"]  # noqa: Y015
    _WhichOneofReturnType__application_frecency: _TypeAlias = _typing.Literal["application_frecency"]  # noqa: Y015
    _WhichOneofArgType__application_frecency: _TypeAlias = _typing.Literal["_application_frecency", b"_application_frecency"]  # noqa: Y015
    _WhichOneofReturnType__emoji_frecency: _TypeAlias = _typing.Literal["emoji_frecency"]  # noqa: Y015
    _WhichOneofArgType__emoji_frecency: _TypeAlias = _typing.Literal["_emoji_frecency", b"_emoji_frecency"]  # noqa: Y015
    _WhichOneofReturnType__emoji_reaction_frecency: _TypeAlias = _typing.Literal["emoji_reaction_frecency"]  # noqa: Y015
    _WhichOneofArgType__emoji_reaction_frecency: _TypeAlias = _typing.Literal["_emoji_reaction_frecency", b"_emoji_reaction_frecency"]  # noqa: Y015
    _WhichOneofReturnType__favorite_emojis: _TypeAlias = _typing.Literal["favorite_emojis"]  # noqa: Y015
    _WhichOneofArgType__favorite_emojis: _TypeAlias = _typing.Literal["_favorite_emojis", b"_favorite_emojis"]  # noqa: Y015
    _WhichOneofReturnType__favorite_gifs: _TypeAlias = _typing.Literal["favorite_gifs"]  # noqa: Y015
    _WhichOneofArgType__favorite_gifs: _TypeAlias = _typing.Literal["_favorite_gifs", b"_favorite_gifs"]  # noqa: Y015
    _WhichOneofReturnType__favorite_soundboard_sounds: _TypeAlias = _typing.Literal["favorite_soundboard_sounds"]  # noqa: Y015
    _WhichOneofArgType__favorite_soundboard_sounds: _TypeAlias = _typing.Literal["_favorite_soundboard_sounds", b"_favorite_soundboard_sounds"]  # noqa: Y015
    _WhichOneofReturnType__favorite_stickers: _TypeAlias = _typing.Literal["favorite_stickers"]  # noqa: Y015
    _WhichOneofArgType__favorite_stickers: _TypeAlias = _typing.Literal["_favorite_stickers", b"_favorite_stickers"]  # noqa: Y015
    _WhichOneofReturnType__guild_and_channel_frecency: _TypeAlias = _typing.Literal["guild_and_channel_frecency"]  # noqa: Y015
    _WhichOneofArgType__guild_and_channel_frecency: _TypeAlias = _typing.Literal["_guild_and_channel_frecency", b"_guild_and_channel_frecency"]  # noqa: Y015
    _WhichOneofReturnType__heard_sound_frecency: _TypeAlias = _typing.Literal["heard_sound_frecency"]  # noqa: Y015
    _WhichOneofArgType__heard_sound_frecency: _TypeAlias = _typing.Literal["_heard_sound_frecency", b"_heard_sound_frecency"]  # noqa: Y015
    _WhichOneofReturnType__played_sound_frecency: _TypeAlias = _typing.Literal["played_sound_frecency"]  # noqa: Y015
    _WhichOneofArgType__played_sound_frecency: _TypeAlias = _typing.Literal["_played_sound_frecency", b"_played_sound_frecency"]  # noqa: Y015
    _WhichOneofReturnType__sticker_frecency: _TypeAlias = _typing.Literal["sticker_frecency"]  # noqa: Y015
    _WhichOneofArgType__sticker_frecency: _TypeAlias = _typing.Literal["_sticker_frecency", b"_sticker_frecency"]  # noqa: Y015
    _WhichOneofReturnType__versions: _TypeAlias = _typing.Literal["versions"]  # noqa: Y015
    _WhichOneofArgType__versions: _TypeAlias = _typing.Literal["_versions", b"_versions"]  # noqa: Y015
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__application_command_frecency) -> _WhichOneofReturnType__application_command_frecency | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__application_frecency) -> _WhichOneofReturnType__application_frecency | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__emoji_frecency) -> _WhichOneofReturnType__emoji_frecency | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__emoji_reaction_frecency) -> _WhichOneofReturnType__emoji_reaction_frecency | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__favorite_emojis) -> _WhichOneofReturnType__favorite_emojis | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__favorite_gifs) -> _WhichOneofReturnType__favorite_gifs | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__favorite_soundboard_sounds) -> _WhichOneofReturnType__favorite_soundboard_sounds | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__favorite_stickers) -> _WhichOneofReturnType__favorite_stickers | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__guild_and_channel_frecency) -> _WhichOneofReturnType__guild_and_channel_frecency | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__heard_sound_frecency) -> _WhichOneofReturnType__heard_sound_frecency | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__played_sound_frecency) -> _WhichOneofReturnType__played_sound_frecency | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__sticker_frecency) -> _WhichOneofReturnType__sticker_frecency | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__versions) -> _WhichOneofReturnType__versions | None: ...

Global___FrecencyUserSettings: _TypeAlias = FrecencyUserSettings  # noqa: Y015



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class ApplicationUserRoleConnection(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    @_typing.final
    class MetadataEntry(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        KEY_FIELD_NUMBER: _builtins.int
        VALUE_FIELD_NUMBER: _builtins.int
        key: _builtins.str
        value: _builtins.str
        def __init__(
            self,
            *,
            key: _builtins.str = ...,
            value: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    METADATA_FIELD_NUMBER: _builtins.int
    PLATFORM_NAME_FIELD_NUMBER: _builtins.int
    PLATFORM_USERNAME_FIELD_NUMBER: _builtins.int
    VERSION_FIELD_NUMBER: _builtins.int
    platform_name: _builtins.str
    platform_username: _builtins.str
    version: _builtins.int
    @_builtins.property
    def metadata(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
    def __init__(
        self,
        *,
        metadata: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
        platform_name: _builtins.str = ...,
        platform_username: _builtins.str = ...,
        version: _builtins.int = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["metadata", b"metadata", "platform_name", b"platform_name", "platform_username", b"platform_username", "version", b"version"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ApplicationUserRoleConnection: _TypeAlias = ApplicationUserRoleConnection  # noqa: Y015



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class MediumUser(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    ID_FIELD_NUMBER: _builtins.int
    USERNAME_FIELD_NUMBER: _builtins.int
    DISCRIMINATOR_FIELD_NUMBER: _builtins.int
    AVATAR_HASH_FIELD_NUMBER: _builtins.int
    BOT_FIELD_NUMBER: _builtins.int
    FLAGS_FIELD_NUMBER: _builtins.int
    EMAIL_FIELD_NUMBER: _builtins.int
    PHONE_FIELD_NUMBER: _builtins.int
    id: _builtins.int
    username: _builtins.str
    discriminator: _builtins.int
    bot: _builtins.bool
    flags: _builtins.int
    @_builtins.property
    def avatar_hash(self) -> _wrappers_pb2.StringValue: ...
    @_builtins.property
    def email(self) -> _wrappers_pb2.StringValue: ...
    @_builtins.property
    def phone(self) -> _wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        id: _builtins.int = ...,
        username: _builtins.str = ...,
        discriminator: _builtins.int = ...,
        avatar_hash: _wrappers_pb2.StringValue | None = ...,
        bot: _builtins.bool = ...,
        flags: _builtins.int = ...,
        email: _wrappers_pb2.StringValue | None = ...,
        phone: _wrappers_pb2.StringValue | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_avatar_hash", b"_avatar_hash", "_email", b"_email", "_phone", b"_phone", "avatar_hash", b"avatar_hash", "email", b"email", "phone", b"phone"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_avatar_hash", b"_avatar_hash", "_email", b"_email", "_phone", b"_phone", "avatar_hash", b"avatar_hash", "bot", b"bot", "discriminator", b"discriminator", "email", b"email", "flags", b"flags", "id", b"id", "phone", b"phone", "username", b"username"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__avatar_hash: _TypeAlias = _typing.Literal["avatar_hash"]  # noqa: Y015
    _WhichOneofArgType__avatar_hash: _TypeAlias = _typing.Literal["_avatar_hash", b"_avatar_hash"]  # noqa: Y015
    _WhichOneofReturnType__email: _TypeAlias = _typing.Literal["email"]  # noqa: Y015
    _WhichOneofArgType__email: _TypeAlias = _typing.Literal["_email", b"_email"]  # noqa: Y015
    _WhichOneofReturnType__phone: _TypeAlias = _typing.Literal["phone"]  # noqa: Y015
    _WhichOneofArgType__phone: _TypeAlias = _typing.Literal["_phone", b"_phone"]  # noqa: Y015
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__avatar_hash) -> _WhichOneofReturnType__avatar_hash | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__email) -> _WhichOneofReturnType__email | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__phone) -> _WhichOneofReturnType__phone | None: ...

Global___MediumUser: _TypeAlias = MediumUser  # noqa: Y015



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class AcknowledgedApplicationDisclosures(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _ApplicationDisclosureType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ApplicationDisclosureTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[AcknowledgedApplicationDisclosures._ApplicationDisclosureType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        APPLICATION_DISCLOSURE_TYPE_UNSPECIFIED_DISCLOSURE: AcknowledgedApplicationDisclosures._ApplicationDisclosureType.ValueType  # 0
        APPLICATION_DISCLOSURE_TYPE_IP_LOCATION: AcknowledgedApplicationDisclosures._ApplicationDisclosureType.ValueType  # 1
        APPLICATION_DISCLOSURE_TYPE_DISPLAYS_ADVERTISEMENTS: AcknowledgedApplicationDisclosures._ApplicationDisclosureType.ValueType  # 2
        APPLICATION_DISCLOSURE_TYPE_PARTNER_SDK_DATA_SHARING_MESSAGE: AcknowledgedApplicationDisclosures._ApplicationDisclosureType.ValueType  # 3

    class ApplicationDisclosureType(_ApplicationDisclosureType, metaclass=_ApplicationDisclosureTypeEnumTypeWrapper): ...
    APPLICATION_DISCLOSURE_TYPE_UNSPECIFIED_DISCLOSURE: AcknowledgedApplicationDisclosures.ApplicationDisclosureType.ValueType  # 0
    APPLICATION_DISCLOSURE_TYPE_IP_LOCATION: AcknowledgedApplicationDisclosures.ApplicationDisclosureType.ValueType  # 1
    APPLICATION_DISCLOSURE_TYPE_DISPLAYS_ADVERTISEMENTS: AcknowledgedApplicationDisclosures.ApplicationDisclosureType.ValueType  # 2
    APPLICATION_DISCLOSURE_TYPE_PARTNER_SDK_DATA_SHARING_MESSAGE: AcknowledgedApplicationDisclosures.ApplicationDisclosureType.ValueType  # 3

    @_typing.final
    class AcknowledgedApplicationDisclosure(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        DISCLOSURE_TYPE_FIELD_NUMBER: _builtins.int
        ACKED_AT_FIELD_NUMBER: _builtins.int
        disclosure_type: Global___AcknowledgedApplicationDisclosures.ApplicationDisclosureType.ValueType
        @_builtins.property
        def acked_at(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            disclosure_type: Global___AcknowledgedApplicationDisclosures.ApplicationDisclosureType.ValueType = ...,
            acked_at: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_acked_at", b"_acked_at", "acked_at", b"acked_at"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_acked_at", b"_acked_at", "acked_at", b"acked_at", "disclosure_type", b"disclosure_type"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__acked_at: _TypeAlias = _typing.Literal["acked_at"]  # noqa: Y015
        _WhichOneofArgType__acked_at: _TypeAlias = _typing.Literal["_acked_at", b"_acked_at"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__acked_at) -> _WhichOneofReturnType__acked_at | None: ...

    ACKED_DISCLOSURES_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def acked_disclosures(self) -> _containers.RepeatedCompositeFieldContainer[Global___AcknowledgedApplicationDisclosures.AcknowledgedApplicationDisclosure]: ...
    def __init__(
        self,
        *,
        acked_disclosures: _abc.Iterable[Global___AcknowledgedApplicationDisclosures.AcknowledgedApplicationDisclosure] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["acked_disclosures", b"acked_disclosures"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AcknowledgedApplicationDisclosures: _TypeAlias = AcknowledgedApplicationDisclosures  # noqa: Y015
